==> testdisk_6.4.1.orig.tar.gz: testdisk-6.4.1/src/file_gif.c <==
/*

    File: file_gif.c

    Copyright (C) 1998-2005 Christophe GRENIER <grenier@cgsecurity.org>
  
    This software is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.
  
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
  
    You should have received a copy of the GNU General Public License along
    with this program; if not, write the Free Software Foundation, Inc., 59
    Temple Place - Suite 330, Boston MA 02111-1307, USA.

 */

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif
#ifdef HAVE_STRING_H
#include <string.h>
#endif
#include "types.h"
#include "photorec.h"

static const char* header_check_gif(const unsigned char *buffer, const unsigned int buffer_size, const unsigned int safe_header_only,  t_file_recovery *file_recovery);
const t_file_hint file_hint_gif= {
  .extension="gif",
  .description="Graphic Interchange Format",
  .min_header_distance=0,
  .min_filesize=42,
  .max_filesize=PHOTOREC_MAX_FILE_SIZE,
  .recover=1,
  .header_check=&header_check_gif,
  .data_check=NULL,
  .file_check=NULL
};
static const char* header_check_gif(const unsigned char *buffer, const unsigned int buffer_size, const unsigned int safe_header_only,  t_file_recovery *file_recovery)
{
  const unsigned char gif_header[6]= { 'G','I','F','8','7','a'};
  const unsigned char gif_header2[6]= { 'G','I','F','8','9','a'};
  if(memcmp(buffer,gif_header,sizeof(gif_header))==0
      || memcmp(buffer,gif_header2,sizeof(gif_header2))==0)
    return file_hint_gif.extension;
  return NULL;
}

==> testdisk_6.5.orig.tar.gz: testdisk-6.5.orig/src/file_gif.c <==
/*

    File: file_gif.c

    Copyright (C) 1998-2006 Christophe GRENIER <grenier@cgsecurity.org>
  
    This software is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.
  
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
  
    You should have received a copy of the GNU General Public License along
    with this program; if not, write the Free Software Foundation, Inc., 51
    Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

 */

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif
#ifdef HAVE_STRING_H
#include <string.h>
#endif
#include <stdio.h>
#include "types.h"
#include "photorec.h"

static const char* header_check_gif(const unsigned char *buffer, const unsigned int buffer_size, const unsigned int safe_header_only,  t_file_recovery *file_recovery);
static void file_check_gif(t_file_recovery *file_recovery);

const t_file_hint file_hint_gif= {
  .extension="gif",
  .description="Graphic Interchange Format",
  .min_header_distance=0,
  .min_filesize=42,
  .max_filesize=PHOTOREC_MAX_FILE_SIZE,
  .recover=1,
  .header_check=&header_check_gif,
  .data_check=NULL,
  .file_check=&file_check_gif
};

static const char* header_check_gif(const unsigned char *buffer, const unsigned int buffer_size, const unsigned int safe_header_only,  t_file_recovery *file_recovery)
{
  const unsigned char gif_header[6]= { 'G','I','F','8','7','a'};
  const unsigned char gif_header2[6]= { 'G','I','F','8','9','a'};
  if(memcmp(buffer,gif_header,sizeof(gif_header))==0
      || memcmp(buffer,gif_header2,sizeof(gif_header2))==0)
    return file_hint_gif.extension;
  return NULL;
}

static void file_check_gif(t_file_recovery *file_recovery)
{
  const unsigned char gif_footer[2]= {0x00, 0x3b};
  file_search_footer(file_recovery, gif_footer,sizeof(gif_footer));
}
